/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.sshd.server.channel;

import java.io.IOException;

import org.apache.sshd.common.channel.Channel;
import org.apache.sshd.common.channel.ChannelAsyncInputStream;
import org.apache.sshd.common.io.IoInputStream;
import org.apache.sshd.common.util.buffer.ByteArrayBuffer;

public class AsyncDataReceiver implements ChannelDataReceiver {

    private ChannelAsyncInputStream in;

    public AsyncDataReceiver(Channel channel) {
        in = new ChannelAsyncInputStream(channel);
    }

    public IoInputStream getIn() {
        return in;
    }

    @Override
    public int data(ChannelSession channel, byte[] buf, int start, int len) throws IOException {
        in.write(new ByteArrayBuffer(buf, start, len));
        return 0;
    }

    @Override
    public void close() throws IOException {
        in.close(false);
    }
}
