/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.sshd.server.command;

import org.apache.sshd.server.ExitCallback;

/**
 * <p>
 * Represents a command, shell or subsystem that can be used to send command.
 * </p>
 *
 * <p>
 * This command have direct streams, meaning those streams will be provided by the ssh server for the shell to use
 * directly. This interface is suitable for implementing commands in java, rather than using external processes. For
 * wrapping such processes or using inverted streams,
 * </p>
 * see {@link org.apache.sshd.server.shell.InvertedShellWrapper}.
 */
public interface Command extends CommandLifecycle, CommandDirectStreamsAware {
    /**
     * Set the callback that the shell has to call when it is closed.
     *
     * @param callback The {@link ExitCallback} to call when shell is closed
     */
    void setExitCallback(ExitCallback callback);
}
